@@ -1,6 +1,6 @@
 # pkgme - A Debian packaging framework
 #
-# Copyright (C) 2010 Canonical Lt.
+# Copyright (C) 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,28 +18,30 @@
 
 from __future__ import absolute_import, unicode_literals
 
-__metaclass__ = type
 __all__ = [
     '__version__',
     'write_packaging',
     ]
 
-
-__version__ = '0.3.1'
+__version__ = '0.4.0'
 
 
 def write_packaging(path, distribution=None, allowed_backend_names=None):
+    """DEPRECATED - Use ``pkgme.api.write_packaging_info`` instead."""
     # Do these imports in the function to reduce the side-effects of importing
-    # pkgme.   This avoids the need for setup.py of the tool being packaged
+    # pkgme.  This avoids the need for setup.py of the tool being packaged
     # from having to find all the imported dependencies when running the
     # extension pkgme_info setup.py command.
-    from pkgme.backend import get_info_for
-    from pkgme.package_files import default_package_file_group
-    from pkgme.write import Writer
-    info = get_info_for(path, allowed_backend_names=allowed_backend_names)
+    from .api import (
+        load_backends,
+        get_all_info,
+        write_packaging_info,
+        )
+    from .info_elements import Distribution
+    from .project_info import override_info
+    backends = load_backends()
+    decision = get_all_info(path, backends, allowed_backend_names)
+    info = decision['info']
     if distribution:
-        from pkgme.info_elements import Distribution
-        from pkgme.project_info import DictInfo, FallbackInfo
-        info = FallbackInfo(DictInfo({Distribution.name: distribution}), info)
-    files = default_package_file_group.get_files(info)
-    Writer().write(files, path)
+        info = override_info(info, {Distribution: distribution})
+    return write_packaging_info(path, info)
