@@ -1,10 +1,14 @@
 import os
 import sys
 
-from fixtures import TestWithFixtures
+from fixtures import TempDir
 from testtools import TestCase
+from treeshape import (
+    FileTree,
+    from_rough_spec,
+    )
 
-from pkgme.backend import (
+from ..backend import (
     Backend,
     BackendSelector,
     EXTERNAL_BACKEND_PATHS,
@@ -19,17 +23,12 @@ from pkgme.backend import (
     StaticLoader,
     WantError,
     )
-from pkgme.project_info import (
+from ..project_info import (
     MultipleExternalHelpersInfo,
     SingleExternalHelperInfo,
     )
-from pkgme.run_script import ScriptUserError
-from pkgme.testing import (
-    ExecutableFileFixture,
-    FileFixture,
-    StaticLoaderFixture,
-    TempdirFixture,
-    )
+from ..run_script import ScriptUserError
+from ..testing import StaticLoaderFixture
 
 
 class TestBackend(TestCase):
@@ -40,18 +39,17 @@ class TestBackend(TestCase):
         self.assertEqual(backend.name, backend.describe())
 
 
-class ExternalHelpersBackendTests(TestCase, TestWithFixtures):
+class ExternalHelpersBackendTests(TestCase):
 
     def make_want_script(self, script, executable=True):
-        tempdir = self.useFixture(TempdirFixture())
-        script_name = ExternalHelpersBackend.WANT_SCRIPT_NAME
-        script_path = os.path.join(tempdir.path, script_name)
         if executable:
-            cls = ExecutableFileFixture
+            permissions = 0700
         else:
-            cls = FileFixture
-        self.useFixture(cls(script_path, script))
-        return tempdir
+            permissions = 0600
+        script_name = ExternalHelpersBackend.WANT_SCRIPT_NAME
+        return self.useFixture(
+            FileTree({script_name: {'content': script,
+                                    'permissions': permissions}}))
 
     def test_describe(self):
         backend = ExternalHelpersBackend(
@@ -145,13 +143,13 @@ class ExternalHelpersBackendTests(TestCase, TestWithFixtures):
         self.assertEqual((10, None), backend.want(tempdir.path))
 
     def test_missing_want_script(self):
-        tempdir = self.useFixture(TempdirFixture())
+        path = self.useFixture(TempDir()).path
         name = self.getUniqueString()
-        backend = ExternalHelpersBackend(name, tempdir.path)
-        e = self.assertRaises(AssertionError, backend.want, tempdir.path)
+        backend = ExternalHelpersBackend(name, path)
+        e = self.assertRaises(AssertionError, backend.want, path)
         self.assertEqual(
             "Backend %s (%s) has no '%s' script"
-            % (name, tempdir.path, ExternalHelpersBackend.WANT_SCRIPT_NAME),
+            % (name, path, ExternalHelpersBackend.WANT_SCRIPT_NAME),
             str(e))
 
     def test_want_script_not_executable(self):
@@ -219,18 +217,18 @@ class ExternalHelpersBackendTests(TestCase, TestWithFixtures):
             str(e))
 
     def test_want_script_run_in_correct_dir(self):
-        cwd_tempdir = self.useFixture(TempdirFixture())
+        cwd_tempdir = self.useFixture(TempDir()).path
         script = """#!%s
 import os
 if os.getcwd() != '%s':
     print "Backend was called in %%s rather than %%s" %% (os.getcwd(), '%s')
 else:
     print 10
-""" % (sys.executable, cwd_tempdir.path, cwd_tempdir.path)
+""" % (sys.executable, cwd_tempdir, cwd_tempdir)
         backend_tempdir = self.make_want_script(script)
         backend = ExternalHelpersBackend(
             self.getUniqueString(), backend_tempdir.path)
-        self.assertEqual((10, None), backend.want(cwd_tempdir.path))
+        self.assertEqual((10, None), backend.want(cwd_tempdir))
 
     def test_get_info_with_multiple(self):
         helpers_path = self.getUniqueString()
@@ -242,18 +240,18 @@ else:
         self.assertEqual(cwd_path, project_info.cwd)
 
     def test_get_info_with_single(self):
-        helpers_tempdir = self.useFixture(TempdirFixture())
+        helpers_tempdir = self.useFixture(TempDir()).path
         info_script_path = os.path.join(
-            helpers_tempdir.path,
+            helpers_tempdir,
             SingleExternalHelperInfo.INFO_SCRIPT_NAME)
         with open(info_script_path, "w"):
             pass
         cwd_path = self.getUniqueString()
         backend = ExternalHelpersBackend(
-            self.getUniqueString(), helpers_tempdir.path)
+            self.getUniqueString(), helpers_tempdir)
         project_info = backend.get_info(cwd_path)
         self.assertIsInstance(project_info, SingleExternalHelperInfo)
-        self.assertEqual(helpers_tempdir.path, project_info.basepath)
+        self.assertEqual(helpers_tempdir, project_info.basepath)
         self.assertEqual(cwd_path, project_info.cwd)
 
 
@@ -368,7 +366,8 @@ class BackendSelectorTests(TestCase):
         backends = [backend1, backend2]
         selector = BackendSelector(backends)
         self.assertEqual(
-            [(10, backend2), (5, backend1)],
+            [{'score': 10, 'backend': backend2, 'reason': None},
+             {'score': 5, 'backend': backend1, 'reason': None}],
             selector.get_eligible_backends(path))
 
     def test_order_by_name_after_score(self):
@@ -381,7 +380,9 @@ class BackendSelectorTests(TestCase):
         backends = [backend1, backend2, backend3]
         selector = BackendSelector(backends)
         self.assertEqual(
-            [(10, backend2), (10, backend3), (5, backend1)],
+            [{'score': 10, 'backend': backend2, 'reason': None},
+             {'score': 10, 'backend': backend3, 'reason': None},
+             {'score': 5, 'backend': backend1, 'reason': None}],
             selector.get_eligible_backends(path))
 
     def test_ineligible_backends_excluded(self):
@@ -393,7 +394,8 @@ class BackendSelectorTests(TestCase):
         backends = [backend1, backend2, backend3]
         selector = BackendSelector(backends)
         self.assertEqual(
-            [(10, backend2), (5, backend1)],
+            [{'score': 10, 'backend': backend2, 'reason': None},
+             {'score': 5, 'backend': backend1, 'reason': None}],
             selector.get_eligible_backends(path))
 
     def test_excludes_non_allowed_backend(self):
@@ -407,45 +409,44 @@ class BackendSelectorTests(TestCase):
         selector = BackendSelector(backends,
                 allowed_backend_names=allowed_backend_names)
         self.assertEqual(
-            [(10, backend2)], selector.get_eligible_backends(path))
+            [{'score': 10, 'backend': backend2, 'reason': None}],
+            selector.get_eligible_backends(path))
 
 
-class ExternalHelpersBackendLoaderTests(TestCase, TestWithFixtures):
+class ExternalHelpersBackendLoaderTests(TestCase):
+
+    def make_tree(self, *args):
+        return self.useFixture(FileTree(from_rough_spec(args)))
 
     def test_loads_no_backends(self):
-        tempdir = self.useFixture(TempdirFixture())
-        loader = ExternalHelpersBackendLoader([tempdir.path])
+        loader = ExternalHelpersBackendLoader([])
         self.assertEqual([], loader.load())
 
     def test_loads_from_one_dir(self):
-        tempdir = self.useFixture(TempdirFixture())
         backend_name = self.getUniqueString()
-        basepath = tempdir.mkdir(backend_name)
-        loader = ExternalHelpersBackendLoader([tempdir.path])
+        tree = self.make_tree(backend_name + '/')
+        loader = ExternalHelpersBackendLoader([tree.path])
         backends = loader.load()
         self.assertEqual(1, len(backends))
         self.assertIsInstance(backends[0], ExternalHelpersBackend)
         self.assertEqual(backend_name, backends[0].name)
-        self.assertEqual(basepath, backends[0].basepath)
+        self.assertEqual(tree.join(backend_name), backends[0].basepath)
 
     def test_loads_from_two_dirs(self):
-        tempdir1 = self.useFixture(TempdirFixture())
-        tempdir2 = self.useFixture(TempdirFixture())
         backend_name1 = self.getUniqueString()
         backend_name2 = self.getUniqueString()
-        tempdir1.mkdir(backend_name1)
-        tempdir2.mkdir(backend_name2)
+        tempdir1 = self.make_tree(backend_name1 + '/')
+        tempdir2 = self.make_tree(backend_name2 + '/')
         loader = ExternalHelpersBackendLoader(
             [tempdir1.path, tempdir2.path])
         backends = loader.load()
         self.assertEqual(2, len(backends))
 
     def test_loads_only_one_instance_of_each_name(self):
-        tempdir1 = self.useFixture(TempdirFixture())
-        tempdir2 = self.useFixture(TempdirFixture())
         backend_name = self.getUniqueString()
-        basepath1 = tempdir1.mkdir(backend_name)
-        tempdir2.mkdir(backend_name)
+        tempdir1 = self.make_tree(backend_name + '/')
+        tempdir2 = self.make_tree(backend_name + '/')
+        basepath1 = tempdir1.join(backend_name)
         loader = ExternalHelpersBackendLoader(
             [tempdir1.path, tempdir2.path])
         backends = loader.load()
@@ -453,19 +454,17 @@ class ExternalHelpersBackendLoaderTests(TestCase, TestWithFixtures):
         self.assertEqual(basepath1, backends[0].basepath)
 
     def test_loads_only_dirs(self):
-        tempdir = self.useFixture(TempdirFixture())
-        tempdir.touch(self.getUniqueString())
-        loader = ExternalHelpersBackendLoader([tempdir.path])
+        path = self.make_tree(self.getUniqueString()).path
+        loader = ExternalHelpersBackendLoader([path])
         self.assertEqual([], loader.load())
 
     def test_ignores_dotdirs(self):
-        tempdir = self.useFixture(TempdirFixture())
-        tempdir.mkdir("." + self.getUniqueString())
-        loader = ExternalHelpersBackendLoader([tempdir.path])
+        dirname = '.%s/' % (self.getUniqueString(),)
+        tempdir = self.make_tree(dirname).path
+        loader = ExternalHelpersBackendLoader([tempdir])
         self.assertEqual([], loader.load())
 
     def test_ignores_missing_dirs(self):
-        self.useFixture(TempdirFixture())
         loader = ExternalHelpersBackendLoader([self.getUniqueString()])
         self.assertEqual([], loader.load())
 
