@@ -5,8 +5,9 @@ import os
 from debian import changelog
 from testtools import TestCase
 from testtools.matchers import StartsWith
+from treeshape import FileTree
 
-from pkgme.info_elements import (
+from ..info_elements import (
     Architecture,
     ApplicationName,
     BuildDepends,
@@ -32,7 +33,7 @@ from pkgme.info_elements import (
     Version,
     WorkingDirectory,
     )
-from pkgme.package_files import (
+from ..package_files import (
     BasicFile,
     Changelog,
     Compat,
@@ -46,14 +47,13 @@ from pkgme.package_files import (
     Rules,
     TemplatePackageFile,
     )
-from pkgme.project_info import DictInfo
-from pkgme.testing import (
+from ..project_info import DictInfo
+from ..testing import (
     AreDesktopValuesFor,
     ControlStanzaHasField,
     ControlStanzaDoesntHaveField,
     ControlSourceStanzaHasField,
     ControlSourceStanzaDoesntHaveField,
-    TempdirFixture,
     )
 
 
@@ -610,21 +610,19 @@ class PackageFileGroupTests(TestCase):
         self.assertEqual(True, foo.overwrite)
 
     def test_extra_files_from_paths(self):
-        tempdir = self.useFixture(TempdirFixture())
-        filename1 = 'foo'
-        filename2 = 'bar'
-        content1 = 'This is foo'
-        content2 = 'This is bar'
-        tempdir.create_file(filename1, content1)
-        tempdir.create_file(filename2, content2)
+        foo_content = self.getUniqueString()
+        tree = self.useFixture(
+            FileTree(
+                {'foo': {'content': foo_content},
+                 'bar': {}}))
         group = PackageFileGroup()
         project_info = DictInfo({
             ExtraFilesFromPaths.name: {
-                'foo.txt': tempdir.abspath(filename1),
-                'debian/install': tempdir.abspath(filename2),
+                'foo.txt': tree.join('foo'),
+                'debian/install': tree.join('bar'),
                 }})
         files = group.get_files(project_info)
         [foo, install] = files
         self.assertEqual('foo.txt', foo.path)
-        self.assertEqual(content1, foo.get_contents())
+        self.assertEqual(foo_content, foo.get_contents())
         self.assertEqual(True, foo.overwrite)
