@@ -1,6 +1,6 @@
 import os
 
-from fixtures import TestWithFixtures
+from fixtures import TempDir
 from testtools import TestCase
 from testtools.matchers import (
     DirExists,
@@ -8,16 +8,17 @@ from testtools.matchers import (
     PathExists,
     )
 
-from pkgme.package_files import PackageFile
-from pkgme.testing import (
-    TempdirFixture,
-    )
-from pkgme.write import (
+from ..package_files import PackageFile
+from ..write import (
     write_file,
     Writer,
     )
 
 
+def abspath(fixture, *segments):
+    return os.path.join(fixture.path, *segments)
+
+
 class SimplePackageFile(PackageFile):
 
     def __init__(self, path, contents="", overwrite=True):
@@ -29,80 +30,80 @@ class SimplePackageFile(PackageFile):
         return self.contents
 
 
-class WriterTests(TestCase, TestWithFixtures):
+class WriterTests(TestCase):
 
     def get_writer(self):
         return Writer()
 
     def do_write(self, tempdir=None):
         if tempdir is None:
-            tempdir = self.useFixture(TempdirFixture())
+            tempdir = self.useFixture(TempDir())
         writer = self.get_writer()
         writer.write(tempdir.path)
         return tempdir
 
     def test_write_creates_target_dir(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
-        target_dir = tempdir.abspath(self.getUniqueString())
+        tempdir = self.useFixture(TempDir())
+        target_dir = abspath(tempdir, self.getUniqueString())
         writer.write(
             [SimplePackageFile(self.getUniqueString())], target_dir)
         self.assertThat(target_dir, DirExists())
 
     def test_write_creates_needed_subdirs(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         subdir = self.getUniqueString()
         package_file = SimplePackageFile(
             os.path.join(subdir, self.getUniqueString()))
         writer.write([package_file], tempdir.path)
-        self.assertThat(tempdir.abspath(subdir), DirExists())
+        self.assertThat(abspath(tempdir, subdir), DirExists())
 
     def test_write_accepts_existing_subdir(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         subdir = self.getUniqueString()
         package_file = SimplePackageFile(
             os.path.join(subdir, self.getUniqueString()))
-        os.makedirs(tempdir.abspath(subdir))
+        os.makedirs(abspath(tempdir, subdir))
         writer.write([package_file], tempdir.path)
-        self.assertThat(tempdir.abspath(subdir), DirExists())
+        self.assertThat(abspath(tempdir, subdir), DirExists())
 
     def test_write_creates_file(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         filename = self.getUniqueString()
         package_file = SimplePackageFile(filename)
         writer.write([package_file], tempdir.path)
-        self.assertThat(tempdir.abspath(filename), PathExists())
+        self.assertThat(abspath(tempdir, filename), PathExists())
 
     def test_write_creates_file_with_correct_contents(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         filename = self.getUniqueString()
         contents = self.getUniqueString()
         package_file = SimplePackageFile(filename, contents=contents)
         writer.write([package_file], tempdir.path)
-        self.assertThat(tempdir.abspath(filename), FileContains(contents))
+        self.assertThat(abspath(tempdir, filename), FileContains(contents))
 
     def test_write_creates_all_files(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         filename1 = self.getUniqueString()
         package_file1 = SimplePackageFile(filename1)
         filename2 = self.getUniqueString()
         package_file2 = SimplePackageFile(filename2)
         writer.write([package_file1, package_file2], tempdir.path)
-        self.assertThat(tempdir.abspath(filename1), PathExists())
-        self.assertThat(tempdir.abspath(filename2), PathExists())
+        self.assertThat(abspath(tempdir, filename1), PathExists())
+        self.assertThat(abspath(tempdir, filename2), PathExists())
 
     def test_write_overwrites(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         original_contents = self.getUniqueString()
         new_contents = self.getUniqueString()
         filename = self.getUniqueString()
-        target_path = tempdir.abspath(filename)
+        target_path = abspath(tempdir, filename)
         write_file(target_path, original_contents)
         package_file = SimplePackageFile(
             filename, contents=new_contents, overwrite=True)
@@ -111,11 +112,11 @@ class WriterTests(TestCase, TestWithFixtures):
 
     def test_write_doesnt_overwrite_files_with_overwrite_False(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         original_contents = self.getUniqueString()
         new_contents = self.getUniqueString()
         filename = self.getUniqueString()
-        target_path = tempdir.abspath(filename)
+        target_path = abspath(tempdir, filename)
         write_file(target_path, original_contents)
         package_file = SimplePackageFile(
             filename, contents=new_contents, overwrite=False)
@@ -124,10 +125,10 @@ class WriterTests(TestCase, TestWithFixtures):
 
     def test_write_encodes_unicode(self):
         writer = self.get_writer()
-        tempdir = self.useFixture(TempdirFixture())
+        tempdir = self.useFixture(TempDir())
         contents = u"\x80"
         filename = self.getUniqueString()
-        target_path = tempdir.abspath(filename)
+        target_path = abspath(tempdir, filename)
         package_file = SimplePackageFile(filename, contents=contents)
         writer.write([package_file], tempdir.path)
         self.assertThat(target_path, FileContains(contents.encode('utf-8')))
